import { useState, useCallback } from "react";
import { useNavigate } from "react-router-dom";
import { Box, Button, Grid, Tooltip, Typography } from "@mui/material";
import { ConfirmDangerActionDialog } from "@ess-ics/ce-ui-common";
import { useCustomSnackbar } from "../../common/snackbar";
import { AccessControl } from "../../auth/AccessControl";
import { useDeleteIocMutation } from "../../../store/enhancedApi";
import { ApiAlertError } from "../../common/Alerts/ApiAlertError";

export const IOCDelete = ({ ioc, buttonDisabled, setButtonDisabled }) => {
  const navigate = useNavigate();
  const showSnackBar = useCustomSnackbar();
  const [error, setError] = useState();
  const [open, setOpen] = useState(false);
  const [deleteIOC] = useDeleteIocMutation();

  let disabledButtonTitle = "";

  if (buttonDisabled || ioc.operationInProgress) {
    disabledButtonTitle =
      "There is an ongoing operation, you can not delete the IOC right now";
  }

  const onClose = useCallback(() => {
    setOpen(false);
  }, [setOpen]);

  const onConfirm = useCallback(async () => {
    setButtonDisabled(true);
    deleteIOC({ iocId: ioc.id })
      .unwrap()
      .then(() => {
        showSnackBar(`IOC ${ioc.namingName} deleted`, "success");
        navigate("/iocs", { replace: true });
      })
      .catch((error) => {
        setError(error);
        setButtonDisabled(false);
      });
  }, [ioc, deleteIOC, setButtonDisabled, navigate, showSnackBar]);

  return (
    <>
      <ConfirmDangerActionDialog
        title="Delete IOC"
        text="Type in the complete IOC name to confirm that you really want to delete the IOC."
        confirmText="Delete IOC"
        open={open}
        valueToCheck={ioc.namingName}
        onClose={onClose}
        onConfirm={onConfirm}
      />

      <Box sx={{ pt: 2 }}>
        <Typography
          sx={{ my: 2.5 }}
          component="h2"
          variant="h3"
        >
          Delete IOC
        </Typography>
        <Grid
          container
          spacing={1}
        >
          {error ? (
            <Grid
              item
              xs={12}
            >
              <ApiAlertError error={error} />
            </Grid>
          ) : (
            <></>
          )}
          <Grid
            item
            xs={12}
          >
            <AccessControl
              allowedRoles={["DeploymentToolAdmin"]}
              renderNoAccess={() => (
                <Tooltip title={"Only admins can delete the IOC"}>
                  <span>
                    <Button
                      color="error"
                      variant="contained"
                      disabled
                    >
                      Delete IOC
                    </Button>
                  </span>
                </Tooltip>
              )}
            >
              <Tooltip title={disabledButtonTitle}>
                <span>
                  <Button
                    onClick={() => setOpen(true)}
                    disabled={
                      buttonDisabled ||
                      ioc.operationInProgress ||
                      Boolean(ioc.activeDeployment)
                    }
                    color="error"
                    variant="contained"
                  >
                    Delete IOC
                  </Button>
                </span>
              </Tooltip>
            </AccessControl>
          </Grid>
        </Grid>
      </Box>
    </>
  );
};
